@@ -6,7 +6,7 @@
 ;; Homepage: https://github.com/ahyatt/triples
 ;; Package-Requires: ((seq "2.0") (emacs "28.1"))
 ;; Keywords: triples, kg, data, sqlite
-;; Version: 0.4.1
+;; Version: 0.5.0
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
 ;; published by the Free Software Foundation; either version 2 of the
@@ -117,7 +117,7 @@ If FILE is nil, use `triples-default-database-filename'."
                   db))
       ('emacsql
        (require 'emacsql)
-       (let* ((db (emacsql-sqlite file))
+       (let* ((db (emacsql-sqlite-open file))
               (triple-table-exists
                (emacsql db [:select name
                                     :from sqlite_master
@@ -433,10 +433,10 @@ merged into NEW-SUBJECT."
               (signal 'error err))))
     ('emacsql
      (emacsql-with-transaction db
-       (emacsql db [:update triples :set (= subject $s1) :where (= subject $s2)]
-                new-subject old-subject)
-       (emacsql db [:update triples :set (= object $s1) :where (= object $s2)]
-                new-subject old-subject)))))
+                               (emacsql db [:update triples :set (= subject $s1) :where (= subject $s2)]
+                                        new-subject old-subject)
+                               (emacsql db [:update triples :set (= object $s1) :where (= object $s2)]
+                                        new-subject old-subject)))))
 
 ;; Code after this point should not call sqlite or emacsql directly. If any more
 ;; calls are needed, put them in a defun, make it work for sqlite and emacsql,
